<?

class nc_payment_system_securepay extends nc_payment_system {

    const ERROR_EPS_ID_IS_NOT_VALID = "Invalid Merchant id";
    const ERROR_EPS_PWD_IS_NOT_VALID = "Password can not be empty";
    const TARGET_LIVE_URL = "https://api.securepay.com.au/live/directpost/authorise";
    const TARGET_TEST_URL = "https://api.securepay.com.au/test/directpost/authorise";

    protected $automatic = TRUE;

    // принимаемые валюты
    protected $accepted_currencies = array('RUB', 'RUR', 'AUD');

    // параметры сайта в платежной системе
    protected $settings = array(
        'EPS_MERCHANT' => null,
        'EPS_TXNPASS' => null,
        'EPS_RESULTURL' => null,
        'EPS_CALLBACKURL' => null,
        'EPS_TEST_MODE' => 0,
    );

    // передаваемые параметры
    protected $request_parameters = array( // 'InvId' => null,
        // 'InvDesc' => null,
    );

    // получаемые параметры
    protected $callback_response = array(
        'refid' => null,
        'summarycode' => null,
	'fingerprint' => null,
	'merchant' => null,
	'timestamp' => null
    );


    /**
     *
     */
    public function execute_payment_request(nc_payment_invoice $invoice) {
        $amount = $invoice->get_amount("%0.2F");
	$currency = ($invoice->get_currency() == 'RUR') ? 'RUB' : $invoice->get_currency();
        $timestamp = gmdate("YmdHis");
        $signature_values = array(
            $this->get_setting('EPS_MERCHANT'),
            $this->get_setting('EPS_TXNPASS'),
            0,
            $invoice->get_id(),
            $amount,
            $timestamp
        );
        $signature = sha1(join("|", $signature_values));

        ob_end_clean();
        $form = "
            <html>
              <body>
                    <form action='" . ($this->get_setting('EPS_TEST_MODE') ? nc_payment_system_securepay::TARGET_TEST_URL : nc_payment_system_securepay::TARGET_LIVE_URL). "' method='post' accept-charset='utf-8'>" .
                    $this->make_inputs(array(
                        'EPS_MERCHANT' => $this->get_setting('EPS_MERCHANT'),
                        'EPS_REDIRECT' => "TRUE",
                        'EPS_TXNTYPE' => 0,
                        'EPS_REFERENCEID' => $invoice->get_id(),
                        'EPS_AMOUNT' => $amount,
                        'EPS_CURRENCY' => $currency,
                        'EPS_TIMESTAMP' => $timestamp,
                        'EPS_FINGERPRINT' => $signature,
                        'EPS_RESULTURL' => $this->get_setting('EPS_RESULTURL'),
                        'EPS_CALLBACKURL' => $this->get_setting('EPS_CALLBACKURL')
                    )) . "
Card number: <input type='text' name='EPS_CARDNUMBER' /><br />
Card expiry (MM/YY): <input type='text' name='EPS_EXPIRYMONTH' /> / <input type='text' name='EPS_EXPIRYYEAR' /><br />
CVV code: <input type='text' name='EPS_CCV' /><br /><br />
<input type='submit' value='Do payment' />
                </form>
                <!-- script>document.forms[0].submit();</script -->
              </body>
            </html>";
        echo $form;
        exit;
    }

    /**
     * @param nc_payment_invoice $invoice
     */
    public function on_response(nc_payment_invoice $invoice = null) {

        $invoice->set('status', nc_payment_invoice::STATUS_SUCCESS);
        $invoice->save();
        $this->on_payment_success($invoice);
        die('SUCCESS');
    }

    /**
     *
     */
    public function validate_payment_request_parameters() {
        if (!$this->get_setting('EPS_MERCHANT')) {
            $this->add_error(nc_payment_system_securepay::ERROR_EPS_ID_IS_NOT_VALID);
        }

        if (!$this->get_setting('EPS_TXNPASS')) {
            $this->add_error(nc_payment_system_securepay::ERROR_EPS_PWD_IS_NOT_VALID);
        }
    }

    /**
     * @param nc_payment_invoice $invoice
     */
    public function validate_payment_callback_response(nc_payment_invoice $invoice = null) {

// file_put_contents("securepay.log",print_r($_REQUEST,1) ); // for debugging

        $their_key = strtoupper($this->get_response_value('fingerprint'));

        $signature_values = array(
            $this->get_response_value('merchant'),
            $this->get_setting('EPS_TXNPASS'),
            $this->get_response_value('refid'),
            $invoice->get_amount("%0.2F"),
            $this->get_response_value('timestamp'),
            $this->get_response_value('summarycode')
        );

        $our_key = strtoupper(sha1(join("|", $signature_values)));
        if (!$invoice || $our_key != $their_key || $this->get_response_value('summarycode')!=1 ) {
            if ($invoice) {
                $invoice->set('status', nc_payment_invoice::STATUS_CALLBACK_ERROR);
                $invoice->save();
            }
	    die('FAIL');
        }
    }

    public function load_invoice_on_callback() {
        return $this->load_invoice($this->get_response_value('refid'));
    }
}

